@@ -2,6 +2,6 @@ mod cont_frac;
 mod quad_surd;
 mod traits;
 
-pub use cont_frac::{ContinuedFraction, PatternContinuedFraction};
+pub use cont_frac::{ContinuedFraction, GeneralContinuedFraction};
 pub use traits::{Irrational, symbols};
 pub use quad_surd::QuadraticSurd;
